==> ntopng-6.2.tar.gz: ntopng-6.2/include/flow_alerts/RemoteToLocalInsecureFlowAlert.h <==
/*
 *
 * (C) 2013-24 - ntop.org
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef _REMOTE_TO_LOCAL_INSECURE_FLOW_ALERT_H_
#define _REMOTE_TO_LOCAL_INSECURE_FLOW_ALERT_H_

#include "ntop_includes.h"

class RemoteToLocalInsecureFlowAlert : public FlowAlert {
 private:
  ndpi_serializer* getAlertJSON(ndpi_serializer* serializer);

 public:
  static FlowAlertType getClassType() {
    return {flow_alert_remote_to_local_insecure_proto, alert_category_security};
  }
  static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };

  RemoteToLocalInsecureFlowAlert(FlowCheck* c, Flow* f) : FlowAlert(c, f){};
  ~RemoteToLocalInsecureFlowAlert(){};

  bool autoAck() const { return false; };

  FlowAlertType getAlertType() const { return getClassType(); }
};

#endif /* _REMOTE_TO_LOCAL_INSECURE_PROTO_ALERT_H_ */

==> ntopng-6.4.tar.gz: ntopng-6.4/include/flow_alerts/RemoteToLocalInsecureFlowAlert.h <==
/*
 *
 * (C) 2013-24 - ntop.org
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 */

#ifndef _REMOTE_TO_LOCAL_INSECURE_FLOW_ALERT_H_
#define _REMOTE_TO_LOCAL_INSECURE_FLOW_ALERT_H_

#include "ntop_includes.h"

class RemoteToLocalInsecureFlowAlert : public FlowAlert {
 private:
  ndpi_serializer* getAlertJSON(ndpi_serializer* serializer);

 public:
  static FlowAlertType getClassType() {
    return {flow_alert_remote_to_local_insecure_proto, alert_category_security};
  }
  static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };

  RemoteToLocalInsecureFlowAlert(FlowCheck* c, Flow* f) : FlowAlert(c, f){setAlertScore(getDefaultScore());};
  ~RemoteToLocalInsecureFlowAlert(){};

  bool autoAck() const { return false; };

  FlowAlertType getAlertType() const { return getClassType(); }
};

#endif /* _REMOTE_TO_LOCAL_INSECURE_PROTO_ALERT_H_ */
